@@ -1,12 +1,12 @@
 from pathlib import Path
 
-from django.contrib import admin
-from django.http import FileResponse
-from django.urls import path
 from python_odt_template import ODTTemplate
 from python_odt_template.django import get_odt_renderer
 from python_odt_template.libreoffice import convert_to_pdf
 
+from django.contrib import admin
+from django.http import FileResponse
+from django.urls import path
 
 outputs_dir = Path("../samples/outputs")
 outputs_dir.mkdir(exist_ok=True)
@@ -16,7 +16,7 @@ inputs_dir = Path("../samples/inputs")
 odt_renderer = get_odt_renderer()
 
 
-def render_odt(request):
+def render_odt(_):
     with ODTTemplate(inputs_dir / "template.odt") as template:
         odt_renderer.render(
             template,
